Local_Regional_Permutations: Perform Local and Regional Permutations

View source: R/permutation.R View source: R/RcppExports.R

Local_Regional_PermutationsR Documentation

Perform Local and Regional Permutations

Description

This function performs local and regional permutations on the spatial transcriptomics data.

Usage

Local_Regional_Permutations(
  permutationMatrix,
  permut_col,
  cellPropMatrix,
  spotGeneMatrix,
  LigandVectorIndex,
  ReceptorVectorIndex,
  null_expression,
  nBoot
)

Arguments

permutationMatrix

A matrix containing permutations.

permut_col

A column matrix of permutations.

cellPropMatrix

A matrix of cell type proportions.

spotGeneMatrix

A matrix of gene expressions at spots.

LigandVectorIndex

A vector of ligand indices.

ReceptorVectorIndex

A vector of receptor indices.

null_expression

A matrix of null expression values.

nBoot

Number of bootstrap iterations.

Value

A matrix with the results of the local and regional permutations.


SpaCCI documentation built on June 8, 2025, 11:50 a.m.