This function infers cell-cell interactions on a global scale using spatial transcriptomics data. It applies permutation testing to identify significant ligand-receptor interactions across all spots.
SpaCCI_global(
gene_spot_df,
spot_cell_prop_df,
spatial_coord,
matching_L_R_pairs,
matching_L_R_pairs_info
)A list containing:
A data frame of inferred interactions across the global scale, including information on ligand and receptor cell types, interaction strength, P-values, and adjusted P-values.
A data frame where the rows are genes and the columns are spots (Spot_IDs), representing gene expression levels across spatial spots.
A data frame of cell type proportions for each spot. The rows represent spots (Spot_IDs), and the columns represent different cell types.
A data frame of the spatial coordinates. The column names should include `c("Spot_ID", "imagerow", "imagecol")`, and the row names must be the Spot_IDs, which is the same as the row names in the cell type proportion data frame or the column names of the gene*spot expression data frame.
A data frame containing matching ligand-receptor pairs. Each row corresponds to a ligand-receptor pair, with columns for ligand_vector and receptor_vector.
A data frame providing additional information for each ligand-receptor pair, such as pathway information.