result_global: result_global data for SpaCCI

result_globalR Documentation

result_global data for SpaCCI

Description

This example dataset is the result of running the run_SpaCCI function. It contains the inferred cell-cell interactions across the global scale.

Usage

data(result_global)

Format

A list containing:

pvalue_df

A data frame of p-values and adjusted p-values for cell-cell interactions.

Details

These objects can be used for testing and running example analyses with the SpaCCI package.

Examples

  data(result_global)
  print(result_global)

SpaCCI documentation built on June 8, 2025, 11:50 a.m.

Related to result_global in SpaCCI...