| result_local | R Documentation |
This dataset contains the results of spatial neighborhood analyses. These objects can be used for testing and running example analyses with the SpaCCI package.
data(result_local)
A list containing:
A list of data frames, each containing p-value results for spatial neighborhoods.
A list of matrices, each containing the spot IDs for specific neighborhoods.
data(result_local)
print(result_local)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.