| result_regional | R Documentation |
This example dataset is the result of running the run_SpaCCI function.
It contains the inferred cell-cell interactions across the regional scale.
data(result_regional)
A list containing:
A data frame of p-values and adjusted p-values for cell-cell interactions.
These objects can be used for testing and running example analyses with the SpaCCI package.
data(result_regional)
print(result_regional)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.