powered by
This example dataset is the result of running the run_SpaCCI function. It contains the inferred cell-cell interactions across the regional scale.
run_SpaCCI
data(result_regional)
A list containing:
A data frame of p-values and adjusted p-values for cell-cell interactions.
These objects can be used for testing and running example analyses with the SpaCCI package.
data(result_regional) print(result_regional)
Run the code above in your browser using DataLab