This function generates a color palette. It selects colors from a predefined color space, and if more colors are needed than are available in the predefined set, it generates a palette using color interpolation.
Usage
scPalette(n)
Value
A character vector of colors in hexadecimal format.
Arguments
n
An integer specifying the number of colors needed.